@@ -12,7 +12,7 @@ class HMA(Indicator):
     Output: a list of floats
     """
 
-    def __init__(self, period: int, input_values: List[float] = None):
+    def __init__(self, period: int, input_values: List[float] = None, input_indicator: Indicator = None):
         super().__init__()
 
         self.period = period
@@ -25,7 +25,7 @@ class HMA(Indicator):
         self.add_sub_indicator(self.wma2)
         self.add_managed_sequence(self.hma)
 
-        self.initialize(input_values)
+        self.initialize(input_values, input_indicator)
 
     def _calculate_new_value(self) -> Any:
         if len(self.wma) < sqrt(self.period):
